RowGroupPlan

Enum RowGroupPlan 

pub(crate) enum RowGroupPlan {
    Global {
        row_groups: Option<Vec<usize>>,
        selection: Option<RowSelection>,
    },
    PerRowGroup(Vec<RowGroupSelection>),
    Conflicting,
}
Row-selection configuration shared by the Arrow reader builders.

Variants



Global

First select row_groups, if provided, and then apply selection across the concatenated rows from those row groups.

This is formed by ArrowReaderBuilder::with_row_groups and ArrowReaderBuilder::with_row_selection.

Fields

row_groups: Option<Vec<usize>>


PerRowGroup(Vec<RowGroupSelection>)

Apply each row-group-local selection independently, in the order supplied.

This is formed by with_row_group_selections on the push decoder and async stream builders.



Conflicting

Mutually exclusive global and per-row-group configuration was supplied. This is reported as an error when the reader is built.

Implementations

Source

impl RowGroupPlan

fn set_row_groups(&mut self, new_row_groups: Vec<usize>)

fn set_row_selection(&mut self, new_selection: RowSelection)

pub(crate) fn set_row_group_selections( &mut self, row_group_selections: Vec<RowGroupSelection>, )

pub(crate) fn conflict_error() -> ParquetError

fn into_global(self) -> Result<(Option<Vec<usize>>, Option<RowSelection>)>