pub(super) fn and_then_mask(
mask: &BooleanBuffer,
other: &RowSelection,
) -> BooleanBufferExpand description
Applies other to the selected rows of mask, preserving the original row domain.
pub(super) fn and_then_mask(
mask: &BooleanBuffer,
other: &RowSelection,
) -> BooleanBufferApplies other to the selected rows of mask, preserving the original row domain.