pub(super) fn and_then_row_selections(
first: &[RowSelector],
second: &[RowSelector],
) -> RowSelectionExpand description
Applies second to the rows selected by first, both selector-backed.
pub(super) fn and_then_row_selections(
first: &[RowSelector],
second: &[RowSelector],
) -> RowSelectionApplies second to the rows selected by first, both selector-backed.