fn append_normalized_selector(
selectors: &mut Vec<RowSelector>,
selector: RowSelector,
)Expand description
Appends a selector while maintaining the normalized selector invariants.
fn append_normalized_selector(
selectors: &mut Vec<RowSelector>,
selector: RowSelector,
)Appends a selector while maintaining the normalized selector invariants.