pub(super) fn limit_selectors(
selectors: Vec<RowSelector>,
limit: usize,
) -> Vec<RowSelector>Expand description
Keeps only the first limit selected rows of selectors.
pub(super) fn limit_selectors(
selectors: Vec<RowSelector>,
limit: usize,
) -> Vec<RowSelector>Keeps only the first limit selected rows of selectors.