pub struct ParquetRecordBatchReader {
array_reader: Box<dyn ArrayReader>,
schema: SchemaRef,
read_plan: ReadPlan,
}Expand description
Reads Parquet data as Arrow [RecordBatch]es
This struct implements the [RecordBatchReader] trait and is an
Iterator<Item = ArrowResult<RecordBatch>> that yields [RecordBatch]es.
Typically, either reads from a file or an in memory buffer Bytes
Created by ParquetRecordBatchReaderBuilder
Fields
array_reader: Box<dyn ArrayReader>schema: SchemaRefread_plan: ReadPlanImplementations
Sourceimpl ParquetRecordBatchReader
impl ParquetRecordBatchReader
Sourcefn next_inner(&mut self) -> Result<Option<RecordBatch>>
fn next_inner(&mut self) -> Result<Option<RecordBatch>>
Returns the next RecordBatch from the reader, or None if the reader
has reached the end of the file.
Returns Result<Option<..>> rather than Option<Result<..>> to
simplify error handling with ?
Sourceimpl ParquetRecordBatchReader
impl ParquetRecordBatchReader
Sourcepub fn try_new<T: ChunkReader + 'static>(
reader: T,
batch_size: usize,
) -> Result<Self>
pub fn try_new<T: ChunkReader + 'static>( reader: T, batch_size: usize, ) -> Result<Self>
Create a new ParquetRecordBatchReader from the provided chunk reader
See ParquetRecordBatchReaderBuilder for more options
Sourcepub fn try_new_with_row_groups(
levels: &FieldLevels,
row_groups: &dyn RowGroups,
batch_size: usize,
selection: Option<RowSelection>,
) -> Result<Self>
pub fn try_new_with_row_groups( levels: &FieldLevels, row_groups: &dyn RowGroups, batch_size: usize, selection: Option<RowSelection>, ) -> Result<Self>
Create a new ParquetRecordBatchReader from the provided RowGroups
Note: this is a low-level interface see ParquetRecordBatchReader::try_new for a
higher-level interface for reading parquet data from a file
Sourcepub(crate) fn new(
array_reader: Box<dyn ArrayReader>,
read_plan: ReadPlan,
) -> Self
pub(crate) fn new( array_reader: Box<dyn ArrayReader>, read_plan: ReadPlan, ) -> Self
Create a new ParquetRecordBatchReader that will read at most batch_size rows at
a time from [ArrayReader] based on the configured selection. If selection is None
all rows will be returned
pub(crate) fn batch_size(&self) -> usize