fn compute_min_max<T>( array: T, valid: impl Iterator<Item = usize>, ) -> Option<(T::Item, T::Item)>where T: ArrayAccessor, T::Item: Copy + Ord + AsRef<[u8]>,
Computes the min and max for the provided array and indices
This is a free function so it can be used with downcast_op!
downcast_op!