fn encode<T, I>(values: T, indices: I, encoder: &mut ByteArrayEncoder)Expand description
Encodes the provided values and indices to encoder
This is a free function so it can be used with downcast_op!
fn encode<T, I>(values: T, indices: I, encoder: &mut ByteArrayEncoder)Encodes the provided values and indices to encoder
This is a free function so it can be used with downcast_op!