ArrayLevels

Struct ArrayLevels 

pub(crate) struct ArrayLevels {
    def_levels: Option<Vec<i16>>,
    rep_levels: Option<Vec<i16>>,
    non_null_indices: Vec<usize>,
    max_def_level: i16,
    max_rep_level: i16,
    array: ArrayRef,
    logical_nulls: Option<NullBuffer>,
}
The data necessary to write a primitive Arrow array to parquet, taking into account any non-primitive parents it may have in the arrow representation

Fields

def_levels: Option<Vec<i16>>

Array’s definition levels

Present if max_def_level != 0

rep_levels: Option<Vec<i16>>

Array’s optional repetition levels

Present if max_rep_level != 0

non_null_indices: Vec<usize>

The corresponding array identifying non-null slices of data from the primitive array

max_def_level: i16

The maximum definition level for this leaf column

max_rep_level: i16

The maximum repetition for this leaf column

array: ArrayRef

The arrow array

logical_nulls: Option<NullBuffer>

cached logical nulls of the array.

Implementations

Source

impl ArrayLevels

fn new(ctx: LevelContext, is_nullable: bool, array: ArrayRef) -> Self

pub fn array(&self) -> &ArrayRef

pub fn def_levels(&self) -> Option<&[i16]>

pub fn rep_levels(&self) -> Option<&[i16]>

pub fn non_null_indices(&self) -> &[usize]

pub(crate) fn slice_for_chunk(&self, chunk: &CdcChunk) -> Self

Create a sliced view of this ArrayLevels for a CDC chunk.

The chunk’s value_offset/num_values select the relevant slice of non_null_indices. The array is sliced to the range covered by those indices, and they are shifted to be relative to the slice.