struct ArrowColumnWriterFactory {
page_store_factory: Arc<dyn PageStoreFactory>,
row_group_index: usize,
file_encryptor: Option<Arc<FileEncryptor>>,
}Expand description
Creates ArrowColumnWriter instances
Fields
page_store_factory: Arc<dyn PageStoreFactory>Allocates the per-column-chunk PageStore backing each page writer.
row_group_index: usizefile_encryptor: Option<Arc<FileEncryptor>>Implementations
Sourceimpl ArrowColumnWriterFactory
impl ArrowColumnWriterFactory
pub fn new() -> Self
Sourcepub fn with_page_store_factory(
self,
page_store_factory: Arc<dyn PageStoreFactory>,
) -> Self
pub fn with_page_store_factory( self, page_store_factory: Arc<dyn PageStoreFactory>, ) -> Self
Use page_store_factory to allocate the buffer for each column chunk.
pub fn with_file_encryptor( self, row_group_index: usize, file_encryptor: Option<Arc<FileEncryptor>>, ) -> Self
fn create_page_writer( &self, column_descriptor: &ColumnDescPtr, column_index: usize, ) -> Result<Box<ArrowPageWriter>>
Sourcefn get_arrow_column_writer(
&self,
data_type: &ArrowDataType,
props: &WriterPropertiesPtr,
leaves: &mut Iter<'_, ColumnDescPtr>,
out: &mut Vec<ArrowColumnWriter>,
) -> Result<()>
fn get_arrow_column_writer( &self, data_type: &ArrowDataType, props: &WriterPropertiesPtr, leaves: &mut Iter<'_, ColumnDescPtr>, out: &mut Vec<ArrowColumnWriter>, ) -> Result<()>
Gets an ArrowColumnWriter for the given data_type, appending the
output ColumnDesc to leaves and the column writers to out