ViewBuffer

Struct ViewBuffer 

pub struct ViewBuffer {
    pub views: Vec<u128>,
    pub buffers: Vec<Buffer>,
}
A buffer of view type byte arrays that can be converted into GenericByteViewArray

Note this does not reuse GenericByteViewBuilder due to the need to call pad_nulls and reuse the existing logic for Vec in the parquet crate

Fields

views: Vec<u128>buffers: Vec<Buffer>

Implementations

Source

impl ViewBuffer

pub fn with_capacity(capacity: usize) -> Self

Create a new ViewBuffer with capacity for the specified number of views

pub fn is_empty(&self) -> bool

pub fn append_block(&mut self, block: Buffer) -> u32

pub fn into_array( self, null_buffer: Option<Buffer>, data_type: &ArrowType, ) -> ArrayRef

Converts this into an [ArrayRef] with the provided data_type and null_buffer