pub(crate) enum RowGroupBuildResult {
Finished {
remaining_budget: RowBudget,
},
NeedsData(Vec<Range<u64>>),
Data {
batch_reader: ParquetRecordBatchReader,
remaining_budget: RowBudget,
},
}Variants
Finished
The active row group is complete without producing a reader.
NeedsData(Vec<Range<u64>>)
More bytes are needed before the active row group can make progress.
Data
The active row group produced a reader.
Fields

batch_reader: ParquetRecordBatchReaderTrait Implementations