RowBudget

Struct RowBudget 

pub(crate) struct RowBudget {
    offset: Option<usize>,
    limit: Option<usize>,
}
Running offset/limit budget shared across row groups.

Fields

offset: Option<usize>limit: Option<usize>

Implementations

Source

impl RowBudget

pub(crate) fn new(offset: Option<usize>, limit: Option<usize>) -> Self

pub(crate) fn is_exhausted(self) -> bool

pub(crate) fn rows_after(self, rows_before_budget: usize) -> usize

Returns how many selected rows remain after applying this budget.

fn selected_row_limit(self) -> Option<usize>

Returns the number of selected rows needed before applying the offset.

fn apply_to_plan( self, plan_builder: ReadPlanBuilder, row_count: usize, ) -> BudgetedReadPlan

pub(crate) fn advance( self, rows_before_budget: usize, rows_after_budget: usize, ) -> Self

Advance the budget past one row group.

rows_before_budget is the number of rows selected before applying the budget, and rows_after_budget is the number retained for output from this row group.