enum QueuedRowGroupDecision {
Read(NextRowGroup),
Skip {
remaining_budget: RowBudget,
},
}Expand description
Plan for the next queued row group after row-selection slicing.
Variants
Read(NextRowGroup)
Hand this row group to the builder.
Skip
Skip this row group, and keep scanning with the updated budget.