pub struct FieldLevels {
pub(crate) fields: Fields,
pub(crate) levels: Option<ParquetField>,
}Expand description
Schema information necessary to decode a parquet file as arrow [Fields]
In particular this stores the dremel-level information necessary to correctly interpret the encoded definition and repetition levels
Note: this is an opaque container intended to be used with lower-level APIs within this crate
Fields
fields: Fieldslevels: Option<ParquetField>Trait Implementations
Sourceimpl Clone for FieldLevels
impl Clone for FieldLevels