CompressionCodec

Enum CompressionCodec 

pub enum CompressionCodec {
    UNCOMPRESSED = 0,
    SNAPPY = 1,
    GZIP = 2,
    LZO = 3,
    BROTLI = 4,
    LZ4 = 5,
    ZSTD = 6,
    LZ4_RAW = 7,
}
Supported compression algorithms.

Codecs added in format version X.Y can be read by readers based on X.Y and later. Codec support may vary between readers based on the format version and libraries available at runtime.

See Compression.md for a detailed specification of these algorithms.

Variants



UNCOMPRESSED = 0



SNAPPY = 1



GZIP = 2



LZO = 3



BROTLI = 4



LZ4 = 5



ZSTD = 6



LZ4_RAW = 7

Implementations

Source

impl CompressionCodec

pub const VARIANTS: &'static [Self]

Returns a slice containing every variant of this enum.

pub const MAX_DISCRIMINANT: i32

Returns the largest discriminant value defined for this enum.

const fn max_discriminant_impl() -> i32