LogicalType

Enum LogicalType 

pub enum LogicalType {
Show 18 variants String, Map, List, Enum, Decimal(DecimalType), Date, Time(TimeType), Timestamp(TimestampType), Integer(IntType), Unknown, Json, Bson, Uuid, Float16, Variant(VariantType), Geometry(GeometryType), Geography(GeographyType), _Unknown { field_id: i16, },
}
Logical types used by version 2.4.0+ of the Parquet format.

This is an entirely new struct as of version 4.0.0. The struct previously named LogicalType was renamed to ConvertedType. Please see the README.md for more details.

Variants



String

A UTF8 encoded string.



Map

A map of key-value pairs.



List

A list of elements.



Enum

A set of predefined values.



Decimal(DecimalType)

A decimal value with a specified scale and precision.



Date

A date stored as days since Unix epoch.



Time(TimeType)

A time stored as TimeUnit since midnight.



Timestamp(TimestampType)

A timestamp stored as TimeUnit since Unix epoch.



Integer(IntType)

An integer with a specified bit width and signedness.



Unknown

An unknown logical type.



Json

A JSON document.



Bson

A BSON document.



Uuid

A UUID.



Float16

A 16-bit floating point number.



Variant(VariantType)

A Variant value.



Geometry(GeometryType)

A geospatial feature in the Well-Known Binary (WKB) format with linear/planar edges interpolation.



Geography(GeographyType)

A geospatial feature in the WKB format with an explicit (non-linear/non-planar) edges interpolation.



_Unknown

Fields

field_id: i16

The field id encountered when parsing the unknown variant.

Implementations

Source

impl LogicalType

pub fn integer(bit_width: i8, is_signed: bool) -> Self

Create a LogicalType::Integer variant with the given bit_width and is_signed

pub fn decimal(scale: i32, precision: i32) -> Self

Create a LogicalType::Decimal variant with the given scale and precision

pub fn time(is_adjusted_to_u_t_c: bool, unit: TimeUnit) -> Self

Create a LogicalType::Time variant with the given is_adjusted_to_u_t_c and unit

pub fn timestamp(is_adjusted_to_u_t_c: bool, unit: TimeUnit) -> Self

Create a LogicalType::Timestamp variant with the given is_adjusted_to_u_t_c and unit

pub fn variant(specification_version: Option<i8>) -> Self

Create a LogicalType::Variant variant with the given specification_version

pub fn geometry(crs: Option<String>) -> Self

Create a LogicalType::Geometry variant with the given crs

pub fn geography( crs: Option<String>, algorithm: Option<EdgeInterpolationAlgorithm>, ) -> Self

Create a LogicalType::Geography variant with the given crs and algorithm