pub enum SortOrder {
SIGNED,
UNSIGNED,
UNDEFINED,
TOTAL_ORDER,
INT96_TIMESTAMP,
}Expand description
Sort order for page and column statistics.
Types are associated with sort orders and column stats are aggregated using a sort order, and a sort order should be considered when comparing values with statistics min/max.
See ColumnOrder for more information.
Variants
SIGNED
Signed (either value or legacy byte-wise) comparison.
UNSIGNED
Unsigned (depending on physical type either value or byte-wise) comparison.
UNDEFINED
Comparison is undefined.
TOTAL_ORDER
Use IEEE 754 total order.
INT96_TIMESTAMP
Use INT96 timestamp order (see parquet-format/#584 and the Thrift spec).
Implementations