pub(crate) struct CdcChunk {
pub level_offset: usize,
pub num_levels: usize,
pub value_offset: usize,
pub num_values: usize,
}Expand description
A chunk of data with level and value offsets for record-shredded nested data.
Fields
level_offset: usizeThe start offset of this chunk inside the given levels.
num_levels: usizeThe number of levels in this chunk.
value_offset: usizeThe start index into non_null_indices for this chunk.
num_values: usizeThe number of non_null_indices entries in this chunk.