update_stat

Function update_stat 

fn update_stat<T: ParquetValueType, F>(val: &T, cur: &mut T, should_update: F)
where F: Fn(&T) -> bool,
Perform a conditional update of cur

Calls should_update with the value of cur, and updates cur to Some(val) if it returns true. cur must not be None or this will panic.