DecryptionPropertiesBuilder

Struct DecryptionPropertiesBuilder 

pub struct DecryptionPropertiesBuilder { /* private fields */ }
Builder for FileDecryptionProperties

See FileDecryptionProperties for example usage.

Implementations

Source

impl DecryptionPropertiesBuilder

pub fn new(footer_key: Vec<u8>) -> DecryptionPropertiesBuilder

Create a new DecryptionPropertiesBuilder builder that will use the provided key to decrypt footer metadata.

pub fn build(self) -> Result<Arc<FileDecryptionProperties>>

Finalize the builder and return created FileDecryptionProperties

pub fn with_aad_prefix(self, value: Vec<u8>) -> Self

Specify the expected AAD prefix to be used for decryption. This must be set if the file was written with an AAD prefix and the prefix is not stored in the file metadata.

pub fn with_column_key(self, column_name: &str, decryption_key: Vec<u8>) -> Self

Specify the decryption key to use for a column

pub fn with_column_keys( self, column_names: Vec<&str>, keys: Vec<Vec<u8>>, ) -> Result<Self>

Specify multiple column decryption keys

Disable verification of footer tags for files that use plaintext footers. Signature verification is enabled by default.