DecryptionPropertiesBuilderWithRetriever

Struct DecryptionPropertiesBuilderWithRetriever 

pub struct DecryptionPropertiesBuilderWithRetriever { /* private fields */ }
Builder for FileDecryptionProperties that uses a KeyRetriever

See the KeyRetriever documentation for example usage.

Implementations

Source

impl DecryptionPropertiesBuilderWithRetriever

pub fn new( key_retriever: Arc<dyn KeyRetriever>, ) -> DecryptionPropertiesBuilderWithRetriever

Create a new DecryptionPropertiesBuilderWithRetriever by providing a KeyRetriever that can be used to get decryption keys based on key metadata.

pub fn build(self) -> Result<Arc<FileDecryptionProperties>>

Finalize the builder and return created FileDecryptionProperties

pub fn with_aad_prefix(self, value: Vec<u8>) -> Self

Specify the expected AAD prefix to be used for decryption. This must be set if the file was written with an AAD prefix and the prefix is not stored in the file metadata.

Disable verification of footer tags for files that use plaintext footers. Signature verification is enabled by default.