dictionary_page_byte_range

Function dictionary_page_byte_range 

fn dictionary_page_byte_range(
    metadata: &ParquetMetaData,
    row_group_idx: usize,
    column_idx: usize,
) -> Result<Option<Range<u64>>>
Returns the [start, end) byte range of a column chunk’s dictionary page, or None if the column chunk has no dictionary page or is not a BYTE_ARRAY column (the only physical type decode_dictionary_page currently supports).