ThriftMetadataWriter

Struct ThriftMetadataWriter 

pub(crate) struct ThriftMetadataWriter<'a, W: Write> {
    buf: &'a mut TrackedWrite<W>,
    schema_descr: &'a SchemaDescPtr,
    row_groups: Vec<RowGroupMetaData>,
    page_index: Option<Arc<dyn PageIndexProvider>>,
    key_value_metadata: Option<Vec<KeyValue>>,
    created_by: Option<String>,
    object_writer: MetadataObjectWriter,
    writer_version: i32,
    write_path_in_schema: bool,
    preserve_page_index_locations: bool,
}
Writes crate::file::metadata structures to a thrift encoded byte stream

See ParquetMetaDataWriter for background and example.

Fields

buf: &'a mut TrackedWrite<W>schema_descr: &'a SchemaDescPtrrow_groups: Vec<RowGroupMetaData>page_index: Option<Arc<dyn PageIndexProvider>>key_value_metadata: Option<Vec<KeyValue>>created_by: Option<String>object_writer: MetadataObjectWriterwriter_version: i32write_path_in_schema: boolpreserve_page_index_locations: bool

Implementations

Source

impl<'a, W: Write> ThriftMetadataWriter<'a, W>

fn write_offset_indexes( &mut self, page_index: &dyn PageIndexProvider, ) -> Result<()>

Serialize all the offset indexes to self.buf,

Note: also updates the ColumnChunk::offset_index_offset and ColumnChunk::offset_index_length to reflect the position and length of the serialized offset indexes.

fn write_column_indexes( &mut self, page_index: &dyn PageIndexProvider, ) -> Result<()>

Serialize all the column indexes to the self.buf

Note: also updates the ColumnChunk::column_index_offset and ColumnChunk::column_index_length to reflect the position and length of the serialized column indexes.

fn clear_page_indexes(&mut self)

pub(crate) fn finish(self) -> Result<ParquetMetaData>

Assembles and writes the final metadata to self.buf

pub(crate) fn new( buf: &'a mut TrackedWrite<W>, schema_descr: &'a SchemaDescPtr, row_groups: Vec<RowGroupMetaData>, created_by: Option<String>, writer_version: i32, write_path_in_schema: bool, preserve_page_index_locations: bool, ) -> Self

pub(crate) fn with_page_index( self, page_index: Arc<dyn PageIndexProvider>, ) -> Self

pub(crate) fn with_key_value_metadata( self, key_value_metadata: Vec<KeyValue>, ) -> Self

pub(crate) fn with_file_encryptor( self, file_encryptor: Option<Arc<FileEncryptor>>, ) -> Self