column_or_default

Function column_or_default 

fn column_or_default<T>(
    column: Option<&ColumnProperties>,
    default: &ColumnProperties,
    get: impl Fn(&ColumnProperties) -> Option<T>,
) -> Option<T>
Returns the setting read by get for column if it sets one, otherwise the setting on default.

column is the per-column override entry, if the column has one.