pub trait Length {
// Required method
fn len(&self) -> u64;
}Expand description
Length should return the total number of bytes in the input source. It’s mainly used to read the metadata, which is at the end of the source.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".