pub enum BloomFilterHash {
XXHASH(XxHash),
}👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Variants
XXHASH(XxHash)
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0