pub enum ColumnCryptoMetaData {
ENCRYPTIONWITHFOOTERKEY(EncryptionWithFooterKey),
ENCRYPTIONWITHCOLUMNKEY(EncryptionWithColumnKey),
}👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Variants
ENCRYPTIONWITHFOOTERKEY(EncryptionWithFooterKey)
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
ENCRYPTIONWITHCOLUMNKEY(EncryptionWithColumnKey)
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0