pub enum EncryptionAlgorithm {
AESGCMV1(AesGcmV1),
AESGCMCTRV1(AesGcmCtrV1),
}👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Variants
AESGCMV1(AesGcmV1)
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
AESGCMCTRV1(AesGcmCtrV1)
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0