pub enum LogicalType {
Show 17 variants
STRING(StringType),
MAP(MapType),
LIST(ListType),
ENUM(EnumType),
DECIMAL(DecimalType),
DATE(DateType),
TIME(TimeType),
TIMESTAMP(TimestampType),
INTEGER(IntType),
UNKNOWN(NullType),
JSON(JsonType),
BSON(BsonType),
UUID(UUIDType),
FLOAT16(Float16Type),
VARIANT(VariantType),
GEOMETRY(GeometryType),
GEOGRAPHY(GeographyType),
}The format module is no longer maintained, and will be removed in 59.0.0
Variants
STRING(StringType)
The format module is no longer maintained, and will be removed in 59.0.0
MAP(MapType)
The format module is no longer maintained, and will be removed in 59.0.0
LIST(ListType)
The format module is no longer maintained, and will be removed in 59.0.0
ENUM(EnumType)
The format module is no longer maintained, and will be removed in 59.0.0
DECIMAL(DecimalType)
The format module is no longer maintained, and will be removed in 59.0.0
DATE(DateType)
The format module is no longer maintained, and will be removed in 59.0.0
TIME(TimeType)
The format module is no longer maintained, and will be removed in 59.0.0
TIMESTAMP(TimestampType)
The format module is no longer maintained, and will be removed in 59.0.0
INTEGER(IntType)
The format module is no longer maintained, and will be removed in 59.0.0
UNKNOWN(NullType)
The format module is no longer maintained, and will be removed in 59.0.0
JSON(JsonType)
The format module is no longer maintained, and will be removed in 59.0.0
BSON(BsonType)
The format module is no longer maintained, and will be removed in 59.0.0
UUID(UUIDType)
The format module is no longer maintained, and will be removed in 59.0.0
FLOAT16(Float16Type)
The format module is no longer maintained, and will be removed in 59.0.0
VARIANT(VariantType)
The format module is no longer maintained, and will be removed in 59.0.0
GEOMETRY(GeometryType)
The format module is no longer maintained, and will be removed in 59.0.0
GEOGRAPHY(GeographyType)
The format module is no longer maintained, and will be removed in 59.0.0