pub enum TimeUnit {
MILLIS(MilliSeconds),
MICROS(MicroSeconds),
NANOS(NanoSeconds),
}👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Variants
MILLIS(MilliSeconds)
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
MICROS(MicroSeconds)
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
NANOS(NanoSeconds)
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0