pub struct BoundaryOrder(pub i32);👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Enum to annotate whether lists of min/max elements inside ColumnIndex are ordered and if so, in which direction.
Tuple Fields
0: i32👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Implementations
Sourceimpl BoundaryOrder
impl BoundaryOrder
pub const UNORDERED: BoundaryOrder
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
pub const ASCENDING: BoundaryOrder
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
pub const DESCENDING: BoundaryOrder
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
pub const ENUM_VALUES: &'static [Self]
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0