pub struct ColumnChunk {
pub file_path: Option<String>,
pub file_offset: i64,
pub meta_data: Option<ColumnMetaData>,
pub offset_index_offset: Option<i64>,
pub offset_index_length: Option<i32>,
pub column_index_offset: Option<i64>,
pub column_index_length: Option<i32>,
pub crypto_metadata: Option<ColumnCryptoMetaData>,
pub encrypted_column_metadata: Option<Vec<u8>>,
}The format module is no longer maintained, and will be removed in 59.0.0
Fields
file_path: Option<String>The format module is no longer maintained, and will be removed in 59.0.0
File where column data is stored. If not set, assumed to be same file as metadata. This path is relative to the current file.
file_offset: i64The format module is no longer maintained, and will be removed in 59.0.0
Deprecated: Byte offset in file_path to the ColumnMetaData
Past use of this field has been inconsistent, with some implementations using it to point to the ColumnMetaData and some using it to point to the first page in the column chunk. In many cases, the ColumnMetaData at this location is wrong. This field is now deprecated and should not be used. Writers should set this field to 0 if no ColumnMetaData has been written outside the footer.
meta_data: Option<ColumnMetaData>The format module is no longer maintained, and will be removed in 59.0.0
Column metadata for this chunk. Some writers may also replicate this at the location pointed to by file_path/file_offset. Note: while marked as optional, this field is in fact required by most major Parquet implementations. As such, writers MUST populate this field.
offset_index_offset: Option<i64>The format module is no longer maintained, and will be removed in 59.0.0
File offset of ColumnChunk’s OffsetIndex *
offset_index_length: Option<i32>The format module is no longer maintained, and will be removed in 59.0.0
Size of ColumnChunk’s OffsetIndex, in bytes *
column_index_offset: Option<i64>The format module is no longer maintained, and will be removed in 59.0.0
File offset of ColumnChunk’s ColumnIndex *
column_index_length: Option<i32>The format module is no longer maintained, and will be removed in 59.0.0
Size of ColumnChunk’s ColumnIndex, in bytes *
crypto_metadata: Option<ColumnCryptoMetaData>The format module is no longer maintained, and will be removed in 59.0.0
Crypto metadata of encrypted columns *
encrypted_column_metadata: Option<Vec<u8>>The format module is no longer maintained, and will be removed in 59.0.0
Encrypted column metadata for this chunk *
Implementations
Sourceimpl ColumnChunk
impl ColumnChunk
pub fn new<F1, F3, F4, F5, F6, F7, F8, F9>( file_path: F1, file_offset: i64, meta_data: F3, offset_index_offset: F4, offset_index_length: F5, column_index_offset: F6, column_index_length: F7, crypto_metadata: F8, encrypted_column_metadata: F9, ) -> ColumnChunk
The format module is no longer maintained, and will be removed in 59.0.0