DictionaryPageHeader

Struct DictionaryPageHeader 

pub struct DictionaryPageHeader {
    pub num_values: i32,
    pub encoding: Encoding,
    pub is_sorted: Option<bool>,
}
👎Deprecated since 57.0.0:

The format module is no longer maintained, and will be removed in 59.0.0

The dictionary page must be placed at the first position of the column chunk if it is partly or completely dictionary encoded. At most one dictionary page can be placed in a column chunk.

Fields

num_values: i32
👎Deprecated since 57.0.0:

The format module is no longer maintained, and will be removed in 59.0.0

Number of values in the dictionary *

encoding: Encoding
👎Deprecated since 57.0.0:

The format module is no longer maintained, and will be removed in 59.0.0

Encoding using this dictionary page *

is_sorted: Option<bool>
👎Deprecated since 57.0.0:

The format module is no longer maintained, and will be removed in 59.0.0

If true, the entries in the dictionary are sorted in ascending order *

Implementations

Source

impl DictionaryPageHeader

pub fn new<F3>( num_values: i32, encoding: Encoding, is_sorted: F3, ) -> DictionaryPageHeader
where F3: Into<Option<bool>>,

👎Deprecated since 57.0.0:

The format module is no longer maintained, and will be removed in 59.0.0