pub struct IntType {
pub bit_width: i8,
pub is_signed: bool,
}👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Integer logical type annotation
bitWidth must be 8, 16, 32, or 64.
Allowed for physical types: INT32, INT64
Fields
bit_width: i8👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
is_signed: bool👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Implementations