pub struct KeyValue {
pub key: String,
pub value: Option<String>,
}👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Wrapper struct to store key values
Fields
key: String👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
value: Option<String>👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Implementations