Struct RowGroup
Source pub struct RowGroup {
pub columns: Vec<ColumnChunk>,
pub total_byte_size: i64,
pub num_rows: i64,
pub sorting_columns: Option<Vec<SortingColumn>>,
pub file_offset: Option<i64>,
pub total_compressed_size: Option<i64>,
pub ordinal: Option<i16>,
}
👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
columns: Vec<ColumnChunk>👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
Metadata for each column chunk in this row group.
This list must have the same order as the SchemaElement list in FileMetaData.
👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
Total byte size of all the uncompressed column data in this row group *
👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
Number of rows in this row group *
sorting_columns: Option<Vec<SortingColumn>>👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
If set, specifies a sort ordering of the rows in this RowGroup.
The sorting columns can be a subset of all the columns.
👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
Byte offset from beginning of file to first page (data or dictionary)
in this row group *
👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
Total byte size of all compressed (and potentially encrypted) column data
in this row group *
👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
Row group ordinal in the file *
👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Compares and returns the maximum of two values.
Read more
Compares and returns the minimum of two values.
Read more
Restrict a value to a certain interval.
Read more
This method returns an ordering between
self and
other values if one exists.
Read more
Tests less than (for
self and
other) and is used by the
< operator.
Read more
Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more
Tests greater than (for
self and
other) and is used by the
>
operator.
Read more
Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more
Reads the struct from the input Thrift protocol
Writes the struct to the output Thrift protocol
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Checks if this value is equivalent to the given key.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.