pub struct SortingColumn {
pub column_idx: i32,
pub descending: bool,
pub nulls_first: bool,
}👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Sort order within a RowGroup of a leaf column
Fields
column_idx: i32👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
The ordinal position of the column (in this row group) *
descending: bool👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
If true, indicates this column is sorted in descending order. *
nulls_first: bool👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
If true, nulls will come before non-null values, otherwise, nulls go at the end.
Implementations