pub struct TimeType {
pub is_adjusted_to_u_t_c: bool,
pub unit: TimeUnit,
}👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Time logical type annotation
Allowed for physical types: INT32 (millis), INT64 (micros, nanos)
Fields
is_adjusted_to_u_t_c: bool👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
unit: TimeUnit👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Implementations