pub struct TimestampType {
pub is_adjusted_to_u_t_c: bool,
pub unit: TimeUnit,
}👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Timestamp logical type annotation
Allowed for physical types: INT64
Fields
is_adjusted_to_u_t_c: bool👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
unit: TimeUnit👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Implementations
Sourceimpl TimestampType
impl TimestampType
pub fn new(is_adjusted_to_u_t_c: bool, unit: TimeUnit) -> TimestampType
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0