Struct Type Copy item path Source pub struct Type(pub i32 );👎 Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
Expand description Types supported by Parquet. These types are intended to be used in combination
with the encodings to control the on disk storage format.
For example INT16 is not included as a type since a good encoding of INT32
would handle this.
👎 Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
👎 Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
👎 Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
👎 Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
👎 Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
👎 Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
👎 Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
👎 Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
👎 Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
👎 Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Compares and returns the maximum of two values.
Read more Compares and returns the minimum of two values.
Read more Restrict a value to a certain interval.
Read more This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more Writes the struct to the output Thrift protocol
Reads the struct from the input Thrift protocol
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Checks if this value is equivalent to the given key.
Read more Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.