ReadThrift

Trait ReadThrift 

pub(crate) trait ReadThrift<'a, R: ThriftCompactInputProtocol<'a>> {
    // Required method
    fn read_thrift(prot: &mut R) -> Result<Self>
       where Self: Sized;
}
Trait implemented for objects that can be deserialized from a Thrift input stream. Implementations are provided for Thrift primitive types.

Required Methods

fn read_thrift(prot: &mut R) -> Result<Self>
where Self: Sized,

Read an object of type Self from the input protocol object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for &'a [u8]

Source

fn read_thrift(prot: &mut R) -> Result<Self>

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for &'a str

Source

fn read_thrift(prot: &mut R) -> Result<Self>

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for String

Source

fn read_thrift(prot: &mut R) -> Result<Self>

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for bool

Source

fn read_thrift(prot: &mut R) -> Result<Self>

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for i8

Source

fn read_thrift(prot: &mut R) -> Result<Self>

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for i16

Source

fn read_thrift(prot: &mut R) -> Result<Self>

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for i32

Source

fn read_thrift(prot: &mut R) -> Result<Self>

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for i64

Source

fn read_thrift(prot: &mut R) -> Result<Self>

Implementors

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for AesGcmCtrV1

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for AesGcmV1

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for BloomFilterAlgorithm

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for BloomFilterCompression

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for BloomFilterHash

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for BloomFilterHeader

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for BoundaryOrder

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for BoundingBox

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for ColumnCryptoMetaData

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for ColumnOrder

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for CompressionCodec

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for ConvertedType

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for DataPageHeader

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for DataPageHeaderV2

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for DecimalType

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for DictionaryPageHeader

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for EdgeInterpolationAlgorithm

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for Encoding

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for EncodingMask

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for EncryptionAlgorithm

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for EncryptionWithColumnKey

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for FieldRepetitionType

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for FileCryptoMetaData<'a>

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for GeographyType

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for GeometryType

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for GeospatialStatistics

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for IndexPageHeader

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for IntType

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for KeyValue

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for LogicalType

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for OffsetIndexMetaData

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for OrderedF64

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for PageEncodingStats

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for PageHeader

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for PageLocation

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for PageStatistics

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for PageType

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for SchemaElement<'a>

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for SizeStatistics

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for SortingColumn

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for Statistics<'a>

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for ThriftColumnIndex<'a>

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for TimeUnit

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for TimestampType

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for Type

Source

impl<'a, R: ThriftCompactInputProtocol<'a>> ReadThrift<'a, R> for VariantType