convert_decimal_to_string

Function convert_decimal_to_string 

fn convert_decimal_to_string(decimal: &Decimal) -> String
Helper method to convert Parquet decimal into a string. We assert that scale >= 0 and precision >= scale, which is enforced when constructing a Parquet schema.