ColumnPath

Struct ColumnPath 

pub struct ColumnPath {
    parts: Vec<String>,
}
Represents the location of a column in a Parquet schema

Example: refer to column named 'my_column'

let column_path = ColumnPath::from("my_column");

Example: refer to column named c in a nested struct {a: {b: {c: ...}}}

// form path 'a.b.c'
let column_path = ColumnPath::from(vec![
  String::from("a"),
  String::from("b"),
  String::from("c")
]);

Fields

parts: Vec<String>

Implementations

Source

impl ColumnPath

pub fn new(parts: Vec<String>) -> Self

Creates new column path from vector of field names.

pub fn string(&self) -> String

Returns string representation of this column path.

use parquet::schema::types::ColumnPath;

let path = ColumnPath::new(vec!["a".to_string(), "b".to_string(), "c".to_string()]);
assert_eq!(&path.string(), "a.b.c");
pub fn append(&mut self, tail: Vec<String>)

Appends more components to end of column path.

use parquet::schema::types::ColumnPath;

let mut path = ColumnPath::new(vec!["a".to_string(), "b".to_string(), "c"
.to_string()]);
assert_eq!(&path.string(), "a.b.c");

path.append(vec!["d".to_string(), "e".to_string()]);
assert_eq!(&path.string(), "a.b.c.d.e");
pub fn parts(&self) -> &[String]

Returns a slice of path components.