expand_to_batch_boundaries_from_selectors

Function expand_to_batch_boundaries_from_selectors 

pub(super) fn expand_to_batch_boundaries_from_selectors<I>(
    selectors: I,
    batch_size: usize,
    total_rows: usize,
) -> RowSelection
where I: IntoIterator<Item = RowSelector>,
Grows each selected run to the batch boundaries containing it, merging the runs that overlap as a result.