pub(super) fn expand_to_batch_boundaries_from_selectors<I>(
selectors: I,
batch_size: usize,
total_rows: usize,
) -> RowSelectionwhere
I: IntoIterator<Item = RowSelector>,Expand description
Grows each selected run to the batch boundaries containing it, merging the runs that overlap as a result.