pub(crate) enum LevelData {
Absent,
Materialized(Vec<i16>),
Uniform {
value: i16,
count: usize,
},
}Expand description
The data necessary to write a primitive Arrow array to parquet, taking into account any non-primitive parents it may have in the arrow representation
Variants
Implementations
Sourceimpl LevelData
impl LevelData
fn new(present: bool) -> Self
pub(crate) fn as_ref(&self) -> LevelDataRef<'_>
pub(crate) fn slice(&self, offset: usize, len: usize) -> Self
fn append_run(&mut self, value: i16, count: usize)
fn extend_from_iter<I>(&mut self, iter: I)where
I: IntoIterator<Item = i16>,
Sourcefn materialize_mut(&mut self) -> Option<&mut Vec<i16>>
fn materialize_mut(&mut self) -> Option<&mut Vec<i16>>
Convert a uniform run into a materialized buffer if needed, then return
the mutable level buffer. Returns None when no physical level stream exists.