pub(crate) struct CdcChunk {
pub level_offset: usize,
pub value_offset: usize,
pub num_levels: usize,
pub num_values: usize,
}Expand description
A chunk of data with level and value offsets for record-shredded nested data.
Fields
level_offset: usizeThe start offset of this chunk inside the given levels.
value_offset: usizeThe start offset of this chunk inside the given values array.
num_levels: usizeThe number of levels in this chunk.
num_values: usizeThe number of values (Arrow array elements) in this chunk.