pub struct BoundingBox {
pub xmin: OrderedFloat<f64>,
pub xmax: OrderedFloat<f64>,
pub ymin: OrderedFloat<f64>,
pub ymax: OrderedFloat<f64>,
pub zmin: Option<OrderedFloat<f64>>,
pub zmax: Option<OrderedFloat<f64>>,
pub mmin: Option<OrderedFloat<f64>>,
pub mmax: Option<OrderedFloat<f64>>,
}The format module is no longer maintained, and will be removed in 59.0.0
Bounding box for GEOMETRY or GEOGRAPHY type in the representation of min/max value pair of coordinates from each axis.
Fields
xmin: OrderedFloat<f64>The format module is no longer maintained, and will be removed in 59.0.0
xmax: OrderedFloat<f64>The format module is no longer maintained, and will be removed in 59.0.0
ymin: OrderedFloat<f64>The format module is no longer maintained, and will be removed in 59.0.0
ymax: OrderedFloat<f64>The format module is no longer maintained, and will be removed in 59.0.0
zmin: Option<OrderedFloat<f64>>The format module is no longer maintained, and will be removed in 59.0.0
zmax: Option<OrderedFloat<f64>>The format module is no longer maintained, and will be removed in 59.0.0
mmin: Option<OrderedFloat<f64>>The format module is no longer maintained, and will be removed in 59.0.0
mmax: Option<OrderedFloat<f64>>The format module is no longer maintained, and will be removed in 59.0.0
Implementations
Sourceimpl BoundingBox
impl BoundingBox