pub struct CompressionCodec(pub i32);The format module is no longer maintained, and will be removed in 59.0.0
Supported compression algorithms.
Codecs added in format version X.Y can be read by readers based on X.Y and later. Codec support may vary between readers based on the format version and libraries available at runtime.
See Compression.md for a detailed specification of these algorithms.
Tuple Fields
0: i32The format module is no longer maintained, and will be removed in 59.0.0
Implementations
Sourceimpl CompressionCodec
impl CompressionCodec
pub const UNCOMPRESSED: CompressionCodec
The format module is no longer maintained, and will be removed in 59.0.0
pub const SNAPPY: CompressionCodec
The format module is no longer maintained, and will be removed in 59.0.0
pub const GZIP: CompressionCodec
The format module is no longer maintained, and will be removed in 59.0.0
pub const LZO: CompressionCodec
The format module is no longer maintained, and will be removed in 59.0.0
pub const BROTLI: CompressionCodec
The format module is no longer maintained, and will be removed in 59.0.0
pub const LZ4: CompressionCodec
The format module is no longer maintained, and will be removed in 59.0.0
pub const ZSTD: CompressionCodec
The format module is no longer maintained, and will be removed in 59.0.0
pub const LZ4_RAW: CompressionCodec
The format module is no longer maintained, and will be removed in 59.0.0
pub const ENUM_VALUES: &'static [Self]
The format module is no longer maintained, and will be removed in 59.0.0