pub struct DataPageHeader {
pub num_values: i32,
pub encoding: Encoding,
pub definition_level_encoding: Encoding,
pub repetition_level_encoding: Encoding,
pub statistics: Option<Statistics>,
}The format module is no longer maintained, and will be removed in 59.0.0
Data page header
Fields
num_values: i32The format module is no longer maintained, and will be removed in 59.0.0
Number of values, including NULLs, in this data page.
If a OffsetIndex is present, a page must begin at a row boundary (repetition_level = 0). Otherwise, pages may begin within a row (repetition_level > 0).
encoding: EncodingThe format module is no longer maintained, and will be removed in 59.0.0
Encoding used for this data page *
definition_level_encoding: EncodingThe format module is no longer maintained, and will be removed in 59.0.0
Encoding used for definition levels *
repetition_level_encoding: EncodingThe format module is no longer maintained, and will be removed in 59.0.0
Encoding used for repetition levels *
statistics: Option<Statistics>The format module is no longer maintained, and will be removed in 59.0.0
Optional statistics for the data in this page *
Implementations
Sourceimpl DataPageHeader
impl DataPageHeader