pub struct GeographyType {
pub crs: Option<String>,
pub algorithm: Option<EdgeInterpolationAlgorithm>,
}The format module is no longer maintained, and will be removed in 59.0.0
Embedded Geography logical type annotation
Geospatial features in the WKB format with an explicit (non-linear/non-planar) edges interpolation algorithm.
A custom geographic CRS can be set by the crs field, where longitudes are bound by [-180, 180] and latitudes are bound by [-90, 90]. If unset, the CRS defaults to โOGC:CRS84โ.
An optional algorithm can be set to correctly interpret edges interpolation of the geometries. If unset, the algorithm defaults to SPHERICAL.
Allowed for physical type: BYTE_ARRAY.
See Geospatial.md for details.
Fields
crs: Option<String>The format module is no longer maintained, and will be removed in 59.0.0
algorithm: Option<EdgeInterpolationAlgorithm>The format module is no longer maintained, and will be removed in 59.0.0
Implementations
Sourceimpl GeographyType
impl GeographyType
pub fn new<F1, F2>(crs: F1, algorithm: F2) -> GeographyType
The format module is no longer maintained, and will be removed in 59.0.0