pub struct RowGroup {
pub columns: Vec<ColumnChunk>,
pub total_byte_size: i64,
pub num_rows: i64,
pub sorting_columns: Option<Vec<SortingColumn>>,
pub file_offset: Option<i64>,
pub total_compressed_size: Option<i64>,
pub ordinal: Option<i16>,
}The format module is no longer maintained, and will be removed in 59.0.0
Fields
columns: Vec<ColumnChunk>The format module is no longer maintained, and will be removed in 59.0.0
Metadata for each column chunk in this row group. This list must have the same order as the SchemaElement list in FileMetaData.
total_byte_size: i64The format module is no longer maintained, and will be removed in 59.0.0
Total byte size of all the uncompressed column data in this row group *
num_rows: i64The format module is no longer maintained, and will be removed in 59.0.0
Number of rows in this row group *
sorting_columns: Option<Vec<SortingColumn>>The format module is no longer maintained, and will be removed in 59.0.0
If set, specifies a sort ordering of the rows in this RowGroup. The sorting columns can be a subset of all the columns.
file_offset: Option<i64>The format module is no longer maintained, and will be removed in 59.0.0
Byte offset from beginning of file to first page (data or dictionary) in this row group *
total_compressed_size: Option<i64>The format module is no longer maintained, and will be removed in 59.0.0
Total byte size of all compressed (and potentially encrypted) column data in this row group *
ordinal: Option<i16>The format module is no longer maintained, and will be removed in 59.0.0
Row group ordinal in the file *
Implementations
Sourceimpl RowGroup
impl RowGroup