pub struct Type(pub i32);The format module is no longer maintained, and will be removed in 59.0.0
Types supported by Parquet. These types are intended to be used in combination with the encodings to control the on disk storage format. For example INT16 is not included as a type since a good encoding of INT32 would handle this.
Tuple Fields
0: i32The format module is no longer maintained, and will be removed in 59.0.0
Implementations
Sourceimpl Type
impl Type
pub const BOOLEAN: Type
The format module is no longer maintained, and will be removed in 59.0.0
pub const INT32: Type
The format module is no longer maintained, and will be removed in 59.0.0
pub const INT64: Type
The format module is no longer maintained, and will be removed in 59.0.0
pub const INT96: Type
The format module is no longer maintained, and will be removed in 59.0.0
pub const FLOAT: Type
The format module is no longer maintained, and will be removed in 59.0.0
pub const DOUBLE: Type
The format module is no longer maintained, and will be removed in 59.0.0
pub const BYTE_ARRAY: Type
The format module is no longer maintained, and will be removed in 59.0.0
pub const FIXED_LEN_BYTE_ARRAY: Type
The format module is no longer maintained, and will be removed in 59.0.0
pub const ENUM_VALUES: &'static [Self]
The format module is no longer maintained, and will be removed in 59.0.0