pub(crate) trait ReadThrift<'a, R: ThriftCompactInputProtocol<'a>> {
// Required method
fn read_thrift(prot: &mut R) -> Result<Self>
where Self: Sized;
}Expand description
Trait implemented for objects that can be deserialized from a Thrift input stream. Implementations are provided for Thrift primitive types.
Required Methods
Sourcefn read_thrift(prot: &mut R) -> Result<Self>where
Self: Sized,
fn read_thrift(prot: &mut R) -> Result<Self>where
Self: Sized,
Read an object of type Self from the input protocol object.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".